@@ -21,6 +21,8 @@
  * Author: David I. Lehn <dlehn@users.sourceforge.net>
  */
 
+#include "gst/gstcaps.h"
+#include "gst/gstminiobject.h"
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
@@ -930,6 +932,393 @@ err:
   return Py_False;
 }
 
+static PyObject *
+_gst_mini_object_make_writable (PyObject * self, PyObject * args)
+{
+  PyObject *py_miniobj, *res;
+  GstMiniObject *mini_object;
+
+  py_miniobj = PyTuple_GetItem (args, 0);
+  if (py_miniobj == NULL) {
+    PyErr_SetString (PyExc_TypeError, "Expected a PyGObject");
+    return NULL;
+  }
+
+  /* Extract GstCaps from Gst.Caps parameter */
+  mini_object = GST_MINI_OBJECT (pygobject_get (py_miniobj));
+  if (!gst_mini_object_is_writable (mini_object)) {
+    GstMiniObject *writable_obj = gst_mini_object_copy (mini_object);
+
+    GST_DEBUG ("Copied miniobject %p to writable miniobject %p", mini_object,
+        writable_obj);
+
+    // Drop our reference to the original miniobject
+    gst_mini_object_unref (mini_object);
+    pyg_boxed_set_ptr (py_miniobj, writable_obj);
+    Py_INCREF (Py_True);
+    res = Py_True;
+  } else {
+    Py_INCREF (Py_False);
+    res = Py_False;
+  }
+
+  return res;
+}
+
+static PyObject *
+_gst_mini_object_flags (PyObject * self, PyObject * args)
+{
+  PyObject *py_miniobj;
+  GstMiniObject *mini_object;
+
+  py_miniobj = PyTuple_GetItem (args, 0);
+  if (py_miniobj == NULL) {
+    PyErr_SetString (PyExc_TypeError, "Expected a PyGObject");
+    return NULL;
+  }
+
+  mini_object = GST_MINI_OBJECT (pygobject_get (py_miniobj));
+  return pyg_flags_from_gtype (gst_mini_object_flags_get_type (),
+      mini_object->flags);
+}
+
+
+static PyObject *
+_gst_mini_object_set_flags (PyObject * self, PyObject * args)
+{
+  PyObject *py_miniobj, *py_flags;
+  GstMiniObject *mini_object;
+
+  py_miniobj = PyTuple_GetItem (args, 0);
+  if (py_miniobj == NULL) {
+    PyErr_SetString (PyExc_TypeError, "Expected a PyGObject");
+    return NULL;
+  }
+
+  mini_object = GST_MINI_OBJECT (pygobject_get (py_miniobj));
+  if (!gst_mini_object_is_writable (mini_object)) {
+
+    PyObject *gstmodule = PyImport_ImportModule ("gi.repository.Gst");
+    PyObject *exc_class =
+        PyObject_GetAttrString (gstmodule, "NotWritableMiniObject");
+    PyObject *args_tuple =
+        PyUnicode_FromFormat ("Trying to set flags on immutable `%s`",
+        g_type_name (GST_MINI_OBJECT_TYPE (mini_object)));
+    PyObject *exc_instance = PyObject_Call (exc_class, args_tuple, NULL);
+
+    PyErr_SetObject (exc_class, exc_instance);
+    Py_DECREF (exc_instance);
+
+    return NULL;
+  }
+
+  py_flags = PyTuple_GetItem (args, 1);
+  if (py_flags == NULL) {
+    PyErr_SetString (PyExc_TypeError, "Expected a flags");
+    return NULL;
+  }
+
+  GstMiniObjectFlags flags;
+  pyg_flags_get_value (gst_mini_object_flags_get_type (), py_flags, &flags);
+
+  mini_object->flags = flags;
+
+  Py_RETURN_NONE;
+}
+
+static PyObject *
+_gst_structure_is_writable (PyObject * self, PyObject * args)
+{
+  PyObject *py_structure, *res;
+  GstStructure *structure;
+
+  py_structure = PyTuple_GetItem (args, 0);
+  if (py_structure == NULL) {
+    PyErr_SetString (PyExc_TypeError, "Expected a PyObject");
+    return NULL;
+  }
+
+  structure = GST_STRUCTURE (pygobject_get (py_structure));
+  if (gst_structure_is_writable (structure)) {
+    Py_INCREF (Py_True);
+    res = Py_True;
+  } else {
+    Py_INCREF (Py_False);
+    res = Py_False;
+  }
+
+  return res;
+}
+
+static PyObject *
+_gst_mini_object_is_writable (PyObject * self, PyObject * args)
+{
+  PyObject *py_miniobj, *res;
+  GstMiniObject *mini_object;
+
+  py_miniobj = PyTuple_GetItem (args, 0);
+  if (py_miniobj == NULL) {
+    PyErr_SetString (PyExc_TypeError, "Expected a PyGObject");
+    return NULL;
+  }
+
+  mini_object = GST_MINI_OBJECT (pygobject_get (py_miniobj));
+  if (gst_mini_object_is_writable (mini_object)) {
+    Py_INCREF (Py_True);
+    res = Py_True;
+  } else {
+    Py_INCREF (Py_False);
+    res = Py_False;
+  }
+
+  return res;
+}
+
+static PyObject *
+_gst_mini_object_to_subclass (PyObject * self, PyObject * args)
+{
+  PyObject *py_miniobj;
+  GstMiniObject *mini_object;
+
+  py_miniobj = PyTuple_GetItem (args, 0);
+  if (py_miniobj == NULL) {
+    PyErr_SetString (PyExc_TypeError, "Expected a PyGObject");
+    return NULL;
+  }
+
+  mini_object = pyg_boxed_get (py_miniobj, GstMiniObject);
+
+  return pyg_boxed_new (GST_MINI_OBJECT_TYPE (mini_object), mini_object, TRUE,
+      TRUE);
+}
+
+static PyObject *
+_gst_caps_get_structure (PyObject * self, PyObject * args)
+{
+  PyTypeObject *gst_caps_type;
+  PyObject *py_caps, *py_structure;
+  GstCaps *caps;
+  gint idx;
+
+  /* Look up Gst.Caps and Gst.Structure parameters */
+  gst_caps_type = pygobject_lookup_class (_gst_caps_type);
+  if (!PyArg_ParseTuple (args, "O!i", gst_caps_type, &py_caps, &idx))
+    return NULL;
+
+  caps = GST_CAPS (pygobject_get (py_caps));
+
+  py_structure = pyg_boxed_new (_gst_structure_type,
+      gst_caps_get_structure (caps, idx), FALSE, FALSE);
+
+  return py_structure;
+}
+
+static PyObject *
+_gst_caps_writable_structure (PyObject * self, PyObject * args)
+{
+  PyTypeObject *gst_caps_type;
+  PyObject *py_caps, *py_structure;
+  GstCaps *caps;
+  gint idx;
+
+  /* Look up Gst.Caps and Gst.Structure parameters */
+  gst_caps_type = pygobject_lookup_class (_gst_caps_type);
+  if (!PyArg_ParseTuple (args, "O!i", gst_caps_type, &py_caps, &idx))
+    return NULL;
+
+  /* Extract GstCaps from Gst.Caps parameter */
+  caps = GST_CAPS (pygobject_get (py_caps));
+  if (!gst_caps_is_writable (caps)) {
+    PyObject *gstmodule = PyImport_ImportModule ("gi.repository.Gst");
+    PyObject *exc_class = PyObject_GetAttrString (gstmodule, "NotWritableCaps");
+    PyObject *args_tuple =
+        PyUnicode_FromFormat ("Trying to write structure on immutable `%s`",
+        g_type_name (GST_MINI_OBJECT_TYPE (caps)));
+    PyObject *exc_instance = PyObject_Call (exc_class, args_tuple, NULL);
+
+    PyErr_SetObject (exc_class, exc_instance);
+    Py_DECREF (exc_instance);
+
+    return NULL;
+  }
+
+  /* Get the structure at the given index */
+  py_structure = pyg_boxed_new (_gst_structure_type,
+      gst_caps_get_structure (caps, idx), FALSE, FALSE);
+
+  return py_structure;
+}
+
+static PyObject *
+_gst_query_get_structure (PyObject * self, PyObject * args)
+{
+  PyTypeObject *gst_query_type;
+  PyObject *py_query, *py_structure;
+  GstQuery *query;
+
+  /* Look up Gst.Query and Gst.Structure parameters */
+  gst_query_type = pygobject_lookup_class (_gst_query_type);
+  if (!PyArg_ParseTuple (args, "O!", gst_query_type, &py_query))
+    return NULL;
+
+  /* Extract GstQuery from Gst.Query parameter */
+  query = GST_QUERY (pygobject_get (py_query));
+
+  /* Get the structure at the given index */
+  py_structure = pyg_boxed_new (_gst_structure_type,
+      (GstStructure *) gst_query_get_structure (query), FALSE, FALSE);
+
+  return py_structure;
+}
+
+static PyObject *
+_gst_query_writable_structure (PyObject * self, PyObject * args)
+{
+  PyTypeObject *gst_query_type;
+  PyObject *py_query, *py_structure;
+  GstQuery *query;
+
+  /* Look up Gst.Query and Gst.Structure parameters */
+  gst_query_type = pygobject_lookup_class (_gst_query_type);
+  if (!PyArg_ParseTuple (args, "O!", gst_query_type, &py_query))
+    return NULL;
+
+  /* Extract GstQuery from Gst.Query parameter */
+  query = GST_QUERY (pygobject_get (py_query));
+  if (!gst_query_is_writable (query)) {
+    PyObject *gstmodule = PyImport_ImportModule ("gi.repository.Gst");
+    PyObject *exc_class =
+        PyObject_GetAttrString (gstmodule, "NotWritableQuery");
+    PyObject *args_tuple = Py_BuildValue ("(s)",
+        "Trying to get writable structure from immutable query");
+    PyObject *exc_instance = PyObject_Call (exc_class, args_tuple, NULL);
+
+    PyErr_SetObject (exc_class, exc_instance);
+    Py_DECREF (exc_instance);
+
+    return NULL;
+  }
+
+  /* Get the structure at the given index */
+  py_structure = pyg_boxed_new (_gst_structure_type,
+      gst_query_writable_structure (query), FALSE, FALSE);
+
+  return py_structure;
+}
+
+static PyObject *
+_gst_event_get_structure (PyObject * self, PyObject * args)
+{
+  PyTypeObject *gst_event_type;
+  PyObject *py_event, *py_structure;
+  GstEvent *event;
+
+  /* Look up Gst.Event and Gst.Structure parameters */
+  gst_event_type = pygobject_lookup_class (_gst_event_type);
+  if (!PyArg_ParseTuple (args, "O!", gst_event_type, &py_event))
+    return NULL;
+
+  /* Extract GstEvent from Gst.Event parameter */
+  event = GST_EVENT (pygobject_get (py_event));
+
+  /* Get the structure at the given index */
+  py_structure = pyg_boxed_new (_gst_structure_type,
+      (GstStructure *) gst_event_get_structure (event), FALSE, FALSE);
+
+  return py_structure;
+}
+
+static PyObject *
+_gst_event_writable_structure (PyObject * self, PyObject * args)
+{
+  PyTypeObject *gst_event_type;
+  PyObject *py_event, *py_structure;
+  GstEvent *event;
+
+  /* Look up Gst.Event and Gst.Structure parameters */
+  gst_event_type = pygobject_lookup_class (_gst_event_type);
+  if (!PyArg_ParseTuple (args, "O!", gst_event_type, &py_event))
+    return NULL;
+
+  /* Extract GstEvent from Gst.Event parameter */
+  event = GST_EVENT (pygobject_get (py_event));
+  if (!gst_event_is_writable (event)) {
+    PyObject *gstmodule = PyImport_ImportModule ("gi.repository.Gst");
+    PyObject *exc_class =
+        PyObject_GetAttrString (gstmodule, "NotWritableEvent");
+    PyObject *args_tuple = Py_BuildValue ("(s)",
+        "Trying to get writable structure from immutable event");
+    PyObject *exc_instance = PyObject_Call (exc_class, args_tuple, NULL);
+
+    PyErr_SetObject (exc_class, exc_instance);
+    Py_DECREF (exc_instance);
+
+    return NULL;
+  }
+
+  /* Get the structure at the given index */
+  py_structure = pyg_boxed_new (_gst_structure_type,
+      gst_event_writable_structure (event), FALSE, FALSE);
+
+  return py_structure;
+}
+
+static PyObject *
+_gst_context_get_structure (PyObject * self, PyObject * args)
+{
+  PyTypeObject *gst_context_type;
+  PyObject *py_context, *py_structure;
+  GstContext *context;
+
+  /* Look up Gst.Context and Gst.Structure parameters */
+  gst_context_type = pygobject_lookup_class (_gst_context_type);
+  if (!PyArg_ParseTuple (args, "O!", gst_context_type, &py_context))
+    return NULL;
+
+  /* Extract GstContext from Gst.Context parameter */
+  context = GST_CONTEXT (pygobject_get (py_context));
+
+  /* Get the structure at the given index */
+  py_structure = pyg_boxed_new (_gst_structure_type,
+      (GstStructure *) gst_context_get_structure (context), FALSE, FALSE);
+
+  return py_structure;
+}
+
+static PyObject *
+_gst_context_writable_structure (PyObject * self, PyObject * args)
+{
+  PyTypeObject *gst_context_type;
+  PyObject *py_context, *py_structure;
+  GstContext *context;
+
+  /* Look up Gst.Context and Gst.Structure parameters */
+  gst_context_type = pygobject_lookup_class (_gst_context_type);
+  if (!PyArg_ParseTuple (args, "O!", gst_context_type, &py_context))
+    return NULL;
+
+  context = GST_CONTEXT (pygobject_get (py_context));
+  if (!gst_context_is_writable (context)) {
+    PyObject *gstmodule = PyImport_ImportModule ("gi.repository.Gst");
+    PyObject *exc_class =
+        PyObject_GetAttrString (gstmodule, "NotWritableContext");
+    PyObject *args_tuple = Py_BuildValue ("(s)",
+        "Trying to get writable structure from immutable context");
+    PyObject *exc_instance = PyObject_Call (exc_class, args_tuple, NULL);
+
+    PyErr_SetObject (exc_class, exc_instance);
+    Py_DECREF (exc_instance);
+
+    return NULL;
+  }
+
+  /* Get the structure at the given index */
+  py_structure = pyg_boxed_new (_gst_structure_type,
+      gst_context_writable_structure (context), FALSE, FALSE);
+
+  return py_structure;
+}
+
 static PyObject *
 _gst_memory_override_unmap (PyObject * self, PyObject * args)
 {
@@ -958,6 +1347,23 @@ _gst_memory_override_unmap (PyObject * self, PyObject * args)
   return success;
 }
 
+
+static PyObject *
+_gst_get_object_ptr (PyObject * self, PyObject * args)
+{
+  PyObject *first_arg;
+
+  first_arg = PyTuple_GetItem (args, 0);
+  gpointer ptr = pygobject_get (first_arg);
+
+  if (ptr == NULL) {
+    PyErr_SetString (PyExc_TypeError, "Expected a PyGObject");
+    return NULL;
+  }
+
+  return PyLong_FromVoidPtr (ptr);
+}
+
 static PyObject *
 _gst_buffer_override_map_range (PyObject * self, PyObject * args)
 {
@@ -1001,6 +1407,203 @@ err:
   return Py_False;
 }
 
+static GstBuffer *
+get_buffer_from_args (PyObject * args)
+{
+  PyTypeObject *gst_buffer_type;
+  PyObject *py_buffer;
+
+  gst_buffer_type = pygobject_lookup_class (_gst_buffer_type);
+  if (!PyArg_ParseTuple (args, "O!", gst_buffer_type, &py_buffer)) {
+    PyErr_BadArgument ();
+    return NULL;
+  }
+
+  return GST_BUFFER (pygobject_get (py_buffer));
+}
+
+#define DECLARE_BUFFER(args) \
+  GstBuffer *buffer = get_buffer_from_args(args); \
+  if (!buffer) return NULL;
+
+static PyObject *
+_gst_buffer_get_dts (PyObject * self, PyObject * args)
+{
+  DECLARE_BUFFER (args);
+
+  return PyLong_FromUnsignedLong (buffer->dts);
+}
+
+static gboolean
+mini_object_check_writability (GstMiniObject * mini_object, const gchar * field)
+{
+  if (!gst_mini_object_is_writable (mini_object)) {
+
+    PyObject *gstmodule = PyImport_ImportModule ("gi.repository.Gst");
+    PyObject *exc_class =
+        PyObject_GetAttrString (gstmodule, "NotWritableMiniObject");
+    PyObject *args_tuple =
+        PyUnicode_FromFormat ("Trying to set %s on immutable `%s`",
+        field, g_type_name (GST_MINI_OBJECT_TYPE (mini_object)));
+    PyObject *exc_instance = PyObject_Call (exc_class, args_tuple, NULL);
+
+    PyErr_SetObject (exc_class, exc_instance);
+    Py_DECREF (exc_instance);
+
+    return FALSE;
+  }
+
+  return TRUE;
+}
+
+
+static PyObject *
+_gst_buffer_set_dts (PyObject * self, PyObject * args)
+{
+  PyTypeObject *gst_buffer_type;
+  PyObject *py_buffer;
+  GstClockTime dts;
+  GstBuffer *buffer;
+
+  gst_buffer_type = pygobject_lookup_class (_gst_buffer_type);
+  if (!PyArg_ParseTuple (args, "O!K", gst_buffer_type, &py_buffer, &dts)) {
+    PyErr_BadArgument ();
+    return NULL;
+  }
+
+  buffer = GST_BUFFER (pygobject_get (py_buffer));
+  if (!mini_object_check_writability (GST_MINI_OBJECT (buffer), "dts"))
+    return NULL;
+
+  buffer->dts = dts;
+
+  Py_RETURN_NONE;
+}
+
+static PyObject *
+_gst_buffer_get_pts (PyObject * self, PyObject * args)
+{
+  DECLARE_BUFFER (args);
+
+  return PyLong_FromUnsignedLong (buffer->pts);
+}
+
+static PyObject *
+_gst_buffer_set_pts (PyObject * self, PyObject * args)
+{
+  PyTypeObject *gst_buffer_type;
+  PyObject *py_buffer;
+  GstClockTime pts;
+  GstBuffer *buffer;
+
+  gst_buffer_type = pygobject_lookup_class (_gst_buffer_type);
+  if (!PyArg_ParseTuple (args, "O!K", gst_buffer_type, &py_buffer, &pts)) {
+    PyErr_BadArgument ();
+    return NULL;
+  }
+
+  buffer = GST_BUFFER (pygobject_get (py_buffer));
+  if (!mini_object_check_writability (GST_MINI_OBJECT (buffer), "pts"))
+    return NULL;
+
+  buffer->pts = pts;
+
+  Py_RETURN_NONE;
+}
+
+static PyObject *
+_gst_buffer_get_duration (PyObject * self, PyObject * args)
+{
+  DECLARE_BUFFER (args);
+
+  return PyLong_FromUnsignedLong (buffer->duration);
+}
+
+static PyObject *
+_gst_buffer_set_duration (PyObject * self, PyObject * args)
+{
+  PyTypeObject *gst_buffer_type;
+  PyObject *py_buffer;
+  GstClockTime duration;
+  GstBuffer *buffer;
+
+  gst_buffer_type = pygobject_lookup_class (_gst_buffer_type);
+  if (!PyArg_ParseTuple (args, "O!K", gst_buffer_type, &py_buffer, &duration)) {
+    PyErr_BadArgument ();
+    return NULL;
+  }
+
+  buffer = GST_BUFFER (pygobject_get (py_buffer));
+  if (!mini_object_check_writability (GST_MINI_OBJECT (buffer), "duration"))
+    return NULL;
+
+  buffer->duration = duration;
+
+  Py_RETURN_NONE;
+}
+
+static PyObject *
+_gst_buffer_get_offset (PyObject * self, PyObject * args)
+{
+  DECLARE_BUFFER (args);
+
+  return PyLong_FromUnsignedLong (buffer->offset);
+}
+
+static PyObject *
+_gst_buffer_set_offset (PyObject * self, PyObject * args)
+{
+  PyTypeObject *gst_buffer_type;
+  PyObject *py_buffer;
+  GstClockTime offset;
+  GstBuffer *buffer;
+
+  gst_buffer_type = pygobject_lookup_class (_gst_buffer_type);
+  if (!PyArg_ParseTuple (args, "O!K", gst_buffer_type, &py_buffer, &offset)) {
+    PyErr_BadArgument ();
+    return NULL;
+  }
+
+  buffer = GST_BUFFER (pygobject_get (py_buffer));
+  if (!mini_object_check_writability (GST_MINI_OBJECT (buffer), "offset"))
+    return NULL;
+
+  buffer->offset = offset;
+
+  Py_RETURN_NONE;
+}
+
+static PyObject *
+_gst_buffer_get_offset_end (PyObject * self, PyObject * args)
+{
+  DECLARE_BUFFER (args);
+
+  return PyLong_FromUnsignedLong (buffer->offset_end);
+}
+
+static PyObject *
+_gst_buffer_set_offset_end (PyObject * self, PyObject * args)
+{
+  PyTypeObject *gst_buffer_type;
+  PyObject *py_buffer;
+  GstClockTime offset_end;
+  GstBuffer *buffer;
+
+  gst_buffer_type = pygobject_lookup_class (_gst_buffer_type);
+  if (!PyArg_ParseTuple (args, "O!K", gst_buffer_type, &py_buffer, &offset_end)) {
+    PyErr_BadArgument ();
+    return NULL;
+  }
+
+  buffer = GST_BUFFER (pygobject_get (py_buffer));
+  if (!mini_object_check_writability (GST_MINI_OBJECT (buffer), "offset_end"))
+    return NULL;
+
+  buffer->offset_end = offset_end;
+
+  Py_RETURN_NONE;
+}
+
 static PyObject *
 _gst_buffer_override_map (PyObject * self, PyObject * args)
 {
@@ -1073,38 +1676,58 @@ _gst_buffer_override_unmap (PyObject * self, PyObject * args)
   return success;
 }
 
+/* *INDENT-OFF* */
 static PyMethodDef _gi_gst_functions[] = {
-  {"trace", (PyCFunction) _wrap_gst_trace, METH_VARARGS,
-      NULL},
-  {"log", (PyCFunction) _wrap_gst_log, METH_VARARGS,
-      NULL},
-  {"debug", (PyCFunction) _wrap_gst_debug, METH_VARARGS,
-      NULL},
-  {"info", (PyCFunction) _wrap_gst_info, METH_VARARGS,
-      NULL},
-  {"warning", (PyCFunction) _wrap_gst_warning, METH_VARARGS,
-      NULL},
-  {"error", (PyCFunction) _wrap_gst_error, METH_VARARGS,
-      NULL},
-  {"fixme", (PyCFunction) _wrap_gst_fixme, METH_VARARGS,
-      NULL},
-  {"memdump", (PyCFunction) _wrap_gst_memdump, METH_VARARGS,
-      NULL},
-  {"buffer_override_map_range", (PyCFunction) _gst_buffer_override_map_range,
-        METH_VARARGS,
-      NULL},
-  {"buffer_override_map", (PyCFunction) _gst_buffer_override_map, METH_VARARGS,
-      NULL},
-  {"buffer_override_unmap", (PyCFunction) _gst_buffer_override_unmap,
-        METH_VARARGS,
-      NULL},
-  {"memory_override_map", (PyCFunction) _gst_memory_override_map, METH_VARARGS,
-      NULL},
-  {"memory_override_unmap", (PyCFunction) _gst_memory_override_unmap,
-        METH_VARARGS,
-      NULL},
+  {"trace", (PyCFunction) _wrap_gst_trace, METH_VARARGS, NULL},
+  {"log", (PyCFunction) _wrap_gst_log, METH_VARARGS, NULL},
+  {"debug", (PyCFunction) _wrap_gst_debug, METH_VARARGS, NULL},
+  {"info", (PyCFunction) _wrap_gst_info, METH_VARARGS, NULL},
+  {"warning", (PyCFunction) _wrap_gst_warning, METH_VARARGS, NULL},
+  {"error", (PyCFunction) _wrap_gst_error, METH_VARARGS, NULL},
+  {"fixme", (PyCFunction) _wrap_gst_fixme, METH_VARARGS, NULL},
+  {"memdump", (PyCFunction) _wrap_gst_memdump, METH_VARARGS, NULL},
+  {"buffer_override_map_range", (PyCFunction) _gst_buffer_override_map_range, METH_VARARGS, NULL},
+  {"buffer_override_map", (PyCFunction) _gst_buffer_override_map, METH_VARARGS, NULL},
+  {"buffer_override_unmap", (PyCFunction) _gst_buffer_override_unmap, METH_VARARGS, NULL},
+  {"memory_override_map", (PyCFunction) _gst_memory_override_map, METH_VARARGS, NULL},
+  {"memory_override_unmap", (PyCFunction) _gst_memory_override_unmap, METH_VARARGS, NULL},
+
+  {"structure_is_writable", (PyCFunction) _gst_structure_is_writable, METH_VARARGS, NULL},
+
+  {"caps_get_structure", (PyCFunction) _gst_caps_get_structure, METH_VARARGS, NULL},
+  {"caps_writable_structure", (PyCFunction) _gst_caps_writable_structure, METH_VARARGS, NULL},
+
+
+  {"mini_object_make_writable", (PyCFunction) _gst_mini_object_make_writable, METH_VARARGS, NULL},
+  {"mini_object_is_writable", (PyCFunction) _gst_mini_object_is_writable, METH_VARARGS, NULL},
+  {"mini_object_flags", (PyCFunction) _gst_mini_object_flags, METH_VARARGS, NULL},
+  {"mini_object_set_flags", (PyCFunction) _gst_mini_object_set_flags, METH_VARARGS, NULL},
+  {"mini_object_to_subclass", (PyCFunction) _gst_mini_object_to_subclass, METH_VARARGS, NULL},
+
+  {"event_get_structure", (PyCFunction) _gst_event_get_structure, METH_VARARGS, NULL},
+  {"event_writable_structure", (PyCFunction) _gst_event_writable_structure, METH_VARARGS, NULL},
+
+  {"query_get_structure", (PyCFunction) _gst_query_get_structure, METH_VARARGS, NULL},
+  {"query_writable_structure", (PyCFunction) _gst_query_writable_structure, METH_VARARGS, NULL},
+
+  {"context_get_structure", (PyCFunction) _gst_context_get_structure, METH_VARARGS, NULL},
+  {"context_writable_structure", (PyCFunction) _gst_context_writable_structure, METH_VARARGS, NULL},
+
+  {"buffer_get_pts", (PyCFunction) _gst_buffer_get_pts, METH_VARARGS, NULL},
+  {"buffer_set_pts", (PyCFunction) _gst_buffer_set_pts, METH_VARARGS, NULL},
+  {"buffer_get_duration", (PyCFunction) _gst_buffer_get_duration, METH_VARARGS, NULL},
+  {"buffer_set_duration", (PyCFunction) _gst_buffer_set_duration, METH_VARARGS, NULL},
+  {"buffer_get_dts", (PyCFunction) _gst_buffer_get_dts, METH_VARARGS, NULL},
+  {"buffer_set_dts", (PyCFunction) _gst_buffer_set_dts, METH_VARARGS, NULL},
+  {"buffer_get_offset", (PyCFunction) _gst_buffer_get_offset, METH_VARARGS, NULL},
+  {"buffer_set_offset", (PyCFunction) _gst_buffer_set_offset, METH_VARARGS, NULL},
+  {"buffer_get_offset_end", (PyCFunction) _gst_buffer_get_offset_end, METH_VARARGS, NULL},
+  {"buffer_set_offset_end", (PyCFunction) _gst_buffer_set_offset_end, METH_VARARGS, NULL},
+
+  {"_get_object_ptr", (PyCFunction) _gst_get_object_ptr, METH_VARARGS, NULL},
   {NULL, NULL, 0, NULL}
 };
+/* *INDENT-ON* */
 
 static const gchar *const *
 py_uri_handler_get_protocols (GType type)
